UQO - You, Quantum and Optimization
---
UQO is an optimization framework developed by the QAR-Lab of the LMU Munich. 

Guides / Examples
---
For setup instructions, guides and examples please visit the Github page: https://github.com/QAR-Lab/uqoclient

Installation
---

 ```
   pip install uqo
```
